import { createFilter } from 'rollup-pluginutils';
import { resolve } from 'source-map-resolve';
import { readFile } from 'fs';

function sourcemaps() {
  var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var include = _ref.include;
  var exclude = _ref.exclude;

  var filter = createFilter(include, exclude);

  return {
    name: 'sourcemaps',

    load: function load(id) {
      if (!filter(id)) {
        return null;
      }

      return new Promise(function (resolve$$1) {
        readFile(id, 'utf8', function (err, code) {
          if (err) {
            // Failed reading file, let the next plugin deal with it
            resolve$$1(null);
          } else {
            resolve(code, id, readFile, function (err, sourceMap) {
              if (err || sourceMap === null) {
                // Either something went wrong, or there was no source map
                resolve$$1(code);
              } else {
                var map = sourceMap.map;
                var sourcesContent = sourceMap.sourcesContent;

                map.sourcesContent = sourcesContent;
                resolve$$1({ code: code, map: map });
              }
            });
          }
        });
      });
    }
  };
}

export default sourcemaps;
//# sourceMappingURL=rollup-plugin-sourcemaps.es.js.map
