'use strict';

var rollupPluginutils = require('rollup-pluginutils');
var sourceMapResolve = require('source-map-resolve');
var fs = require('fs');

function sourcemaps() {
  var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var include = _ref.include;
  var exclude = _ref.exclude;

  var filter = rollupPluginutils.createFilter(include, exclude);

  return {
    name: 'sourcemaps',

    load: function load(id) {
      if (!filter(id)) {
        return null;
      }

      return new Promise(function (resolve$$1) {
        fs.readFile(id, 'utf8', function (err, code) {
          if (err) {
            // Failed reading file, let the next plugin deal with it
            resolve$$1(null);
          } else {
            sourceMapResolve.resolve(code, id, fs.readFile, function (err, sourceMap) {
              if (err || sourceMap === null) {
                // Either something went wrong, or there was no source map
                resolve$$1(code);
              } else {
                var map = sourceMap.map;
                var sourcesContent = sourceMap.sourcesContent;

                map.sourcesContent = sourcesContent;
                resolve$$1({ code: code, map: map });
              }
            });
          }
        });
      });
    }
  };
}

module.exports = sourcemaps;
//# sourceMappingURL=rollup-plugin-sourcemaps.js.map
